*//--------------------------------------------
*//	Title   : Example 3 - an additional pad and menu 
*//			              with a submenu
*// Article : Object Oriented Menu Wrapper classes for VFP 6.0
*//	Author  : Colin Nicholls
*// Email   : 100240.630@compuserve.com
*// Date    : 25.Sep.1998
*//--------------------------------------------

#define MENU_CLASSLIB	'menus6.vcx'

#include menus6.h

*//		Make the menu object PUBLIC so we can reference
*//		it outside the program:

public oMenu

*//		Create an instance of the '_MnuMenubar' class
*//		using NEWOBJECT( class, library, app, params )

oMenu = newobject( '_mnuMenubar', MENU_CLASSLIB,"",n_MNU_APPEND )

*//		Add a 'menu popup' object to the 'menu bar'
*//		container object:
*//		Parameters are ( ObjectName, Prompt )

oMenu.AddMenu( 'Extra', 'E\<xtra' )

*//		Add bars to the popup:

oMenu.Extra.AddBar( 'Bar1', '\<Test One')
with oMenu.Extra.Bar1
	.Command 		= "wait window 'Hello Test 1'"
	.Message	 	= "This is test one's message"
	.KeyShortCut 	= "Ctrl-F12"
	.KeySCText		= "Ctrl-F12"
endwith

*//		Add a separator:

oMenu.Extra.AddBar( 'SP100', '\-' )
	
*//		Add another bar, this time with a different font:	
	
oMenu.Extra.AddBar( 'Bar2', 'Test \<2' )
with oMenu.Extra.Bar2
	.Command 		= "wait window 'Hello Test 2'"
	.Message		= "This is test two's message"
	.KeyShortCut 	= "Ctrl-F11"
	.FontName 		= 'Arial'
	.FontSize		= 12
	.FontBold		= TRUE
endwith

*//		Add a submenu to the 'Extra' menu:

oMenu.Extra.AddMenu( 'SubMenu', '\<Submenu' )

*//		Define the bars of the submenu:

oMenu.Extra.SubMenu.AddBar( 'one', 'Hello' )
oMenu.Extra.SubMenu.AddBar( 'two', 'Goodbye' )

*//		Now, actually construct the menu system -
*//		Append the menu to the system menu bar:

oMenu.Define()

*//		Each objects .Define() method will perform
*//		the menu construction statements required to
*//		build the menu. 


*//		Now try the following commands in the 
*//		command window:

*	oMenu.Extra.Enabled = .F.
*	oMenu.Extra.Enabled = .T.

*	oMenu.Extra.Bar2.Enabled = .F.
*	oMenu.Extra.Bar2.Enabled = .T.

*	oMenu.Extra.Submenu.One.Command = "wait window 'Hello'"
*	oMenu.Extra.Submenu.Two.Command = "wait window 'Goodbye'"
*	oMenu.Refresh()

*	oMenu.Extra.Submenu.One.Caption = "Bonjour"
*	oMenu.Extra.Submenu.Two.Caption = "Au Revour"

*	oMenu.Extra.SubMenu.AddBar('three', 'Back Soon')

*	oMenu.Extra.Submenu.controls[2].Caption = "new prompt"

*	release oMenu

*//		The menu object, along with 
*//		its child objects, should all be released, 
*//		executing code to remove their pads and popups
*//		from the menu as they .Destroy() themselves.
